==> glpi_0.80.7.orig.tar.gz: glpi/ajax/dropdownMassiveActionAddActor.php <==
<?php
/*
 * @version $Id: dropdownMassiveActionAddActor.php 17154 2012-01-24 11:27:36Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2012 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file: Julien Dombre
// Purpose of file:
// ----------------------------------------------------------------------

$AJAX_INCLUDE = 1;
define('GLPI_ROOT','..');
include (GLPI_ROOT."/inc/includes.php");

header("Content-Type: text/html; charset=UTF-8");
header_nocache();

checkRight('update_ticket', 1);

if ($_POST["actortype"] > 0) {
   $rand = mt_rand();
   Ticket::showActorAddForm($_POST["actortype"], $rand, $_SESSION['glpiactive_entity'], false);
   echo "&nbsp;<input type='submit' name='add_actor' class='submit' value=\"".$LANG['buttons'][2]."\">";
}

?>

==> glpi_0.83.orig.tar.gz: glpi/ajax/dropdownMassiveActionAddActor.php <==
<?php
/*
 * @version $Id: dropdownMassiveActionAddActor.php 18071 2012-03-28 08:59:09Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2012 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file: Julien Dombre
// Purpose of file:
// ----------------------------------------------------------------------

$AJAX_INCLUDE = 1;
define('GLPI_ROOT','..');
include (GLPI_ROOT."/inc/includes.php");

header("Content-Type: text/html; charset=UTF-8");
Html::header_nocache();

Session::checkRight('update_ticket', 1);

if ($_POST["actortype"] > 0) {
   $rand = mt_rand();
   Ticket::showActorAddForm($_POST["actortype"], $rand, $_SESSION['glpiactive_entity'], array(), true, false, false);
   echo "&nbsp;<input type='submit' name='add_actor' class='submit' value=\"".$LANG['buttons'][2]."\">";
}

?>
